<% 'Module: Valid_Data_Check.inc

   'Description: This <include> file contains three utility subroutines that are used
   ' to validate input data (i.e. form fields or parameters on URL strings) in terms
   ' of suspicious security behavior and re-act accordingly
   
   ' The first subroutine (Field_Validation_Check) expects 2 parameters
   '   1) A string which is the name of the field being checked, e.g. "Description"
   '   2) A string containing the contents of the field being checked e.g. "This is what the user typed in"
   ' Three types of violation are checked for -
   '   1) String contains a semi-colon
   '   2) String contains 2 or more single quotes
   '   3) String contains two hyphens in immediate juxtaposition
   ' If one or more of these conditions is detected, this subroutine then calls the second one i.e."Bad_Data_Detected"
   
   ' The second subroutine (Bad_Data_Detected) expects 3 parameters
   '   1) A string which is the name of the field being checked, e.g. "Description"
   '   2) A string containing the contents of the field being checked e.g. "This is what the user typed in"
   '   3) An error-code that provides an indication of what violation(s) were detected
   ' This subroutine then performs two major functions
   '   1) Outputs an HTML page to the user informing of the situation
   '   2) Optionally (if enabled by the Systems Administrator) calls the third subroutine (SendEmail) to emit
   '      an email containing usefull details to assist tracing a problem user
   ' This subroutine *does*not* return to whence it was called. It stops execution after the HTML has been painted 
   ' to the screen and the email has been sent. 
   ' It is up to the user to either press "back" and try again, or go do something else.
   
   ' The Third Subroutine (SendEmail) expects the same three parameters as above as well as ome others as
   ' described below. It uses these to create an email containing these three together with some other 
   ' supporting information and sends it

   '(C) 2000, 2003 Internet Software Sciences
   ' www.inet-sciences.com


   'History:

   'Date	Who		What
   '-------	---		------------------------------------------------
   '04/07/2003	JC		Created original version of these support subroutines


%>
<% Sub Field_Validation_Check (check_field_descr, check_field_value) %>
<%

' We expect 2 parameters, the literal name of the field, and its contents

Testfield = check_field_value
Testname = check_field_descr

If isNull(testfield) or testfield = "" Then
 'do nothing
Else
  health_check = 0
  Loc1 =  Instr(testfield, ";")           ' check for presence of semi-colon
  If Loc1 <> 0 Then
     health_check = health_check + 1      ' Add 1 to health_check if there was a semi colon present
  End If
  Loc2 =  Instr(testfield, "'")           ' Find location of *first* single-quote
  If Loc2 <> 0 Then                       ' if there is a single quote present
    Loc3 =  InstrRev(testfield, "'")      ' Find location of *last* single-quote
      If Loc2 <> Loc3 Then                ' If location of first and last single quote were different
        health_check = health_check + 2
      End If                              ' endif location of first and last single quote were different
  End If                                  ' endif there was a single quote present
  Loc4 =  Instr(testfield, "--")          ' find location of double hyphen
  If Loc4 <> 0 Then                       ' If there is a double hyphen present
     health_check = health_check + 4
  End If                                  ' endif there is a double hyphen present
  If health_check <> 0 Then                              ' If any of the above tests were positive
    Bad_Data_Detected Testname, Testfield, health_check  ' take evasive action
  End If                                                 ' endif any of the above tests were positive
End If ' the test field was empty

    %>
<% End Sub ' End of Field_Validation_Check  %>






<% Sub Bad_Data_Detected (xcheck_field_descr, xcheck_field_value, xerror_code)

    ' xcheck_field_descr contains string with name of the data field in question
    ' xcheck_field_value contains the value in the data field in question
    ' xerror_code value 1 means semi-colon is present
    ' xerror_code value 2 means multiple single-quotes present
    ' xerror_code value 4 means two contiguous hyphens present
    ' the above  error codes are addititve - i.e. a code=7 means all 3 violations are present
    ' xerror_code value 99 means a difference was detected between what was typed in and what was (apparently successfully) retrieved from the database for UN or PWD
    

%>
    
<html><!-- (C) 1996,1998, 1999, 2000, 2001, 2003 by Internet Software Sciences-->
<head>
<title><%=wc_Invalid_Data%></title>
</head>
<body bgcolor=silver>
<center>
<table border=1 cellspacing=2 cellpadding=10 bgcolor=yellow>
<tr>
<td>
  <font size=+1><b><%=wc_Invalid_Data%></b></font><P>
  <font color=blue><b><%=wc_For_the_Field%>: </font> <%=xcheck_field_descr%></b><br>
  <font color=blue><b> <%=wc_The_Value%>: </font> <%=xcheck_field_value%></b><br>
  <font color=blue><b> <%=wc_Is_Unacceptable%></font> (Error code=</font> <%=xerror_code%>)</b><p>
  <%=wc_Please_press_back_and_try_again%>
</td>
</tr>
</table><p>
</center>
</body>
</html>
    
<%

' Next we need to assemble 7 parameters to get ready to send an email,  which will look like this:

'                          1         2           3            4                 5                    6                   7
' SendEmailValidData   ToEmail, ToFullName, SubjectLine, TotalMessage, OrganizationFromName, smtp_host_address, Standard_reply_to_address
' comes from            db(tech)  db(tech)    literal       gen dynamic         db(config)        db(config)            db(config)

' (the last line above is just a reminder of where the data is to come from)


' First we go fish out necessary values from the database
' Pick up the name of our suspected violator based on CookieID if possible
' We try two times using
'  a) Cookie ISS_TECH_CENTER_LOGIN to access Tech_staff table
'  b) Cookie ISS_Customer to access customers table


	
	
Set Conn = Server.CreateObject("ADODB.Connection")	
conn.open myDSN	

Set NewRecord = Server.CreateObject("ADODB.Recordset")
MemberNameFound = "No"
MemberName = "Unknown User Not Yet Logged In"
CookieID = Request.Cookies("ISS_TECH_CENTER_LOGIN")
SQL = "Select * from Tech_staff where Tech_ID = '" & CookieID & "'"
NewRecord.Open SQL,Conn,3,3
If NewRecord.EOF <> True Then
	MemberName = NewRecord("First_Name") & " " & NewRecord("Last_Name")
        MemberNameFound = "Yes"	
End If	

If MemberNameFound = "No" Then
     CookieID = Request.Cookies("ISS_Customer")
     SQL = "Select * from Customers where Customer_ID = '" & CookieID & "'"
     set rstemp=conn.execute(SQL)
     If rstemp.EOF <> True Then
        MemberName = rstemp("Contact_Fname") & " " & rstemp("Contact_Lname")
        MemberNameFound = "Yes"	
     End If  
End If   

' Pick up the "to" email address and a name from Tech staff who has an email address and Configurator privileges

mySQL2="select * from Tech_staff where tech_level > 4 and work_email <> '' and  work_email is not null order by tech_level desc"

' the "order by" in this sql statement should give us somebody with tech_level 6, otherwise go for a 5 in desperation

set rstemp=conn.execute(mySQL2)
If rstemp.EOF = True Then
    ' there is nobody to send email to - so we just quit right now
    response.write "<p> Action Suspended<p>"
    response.flush
    response.end
else
   ToEmail = rstemp("work_email")
   ToFullName = rstemp("first_name") & " " & rstemp("Last_name")
end if

' pick up the smtp host address and standard_reply_to address and OrganizationFromName from configuration db
mySQL2="select * from Configuration"
set rstemp=conn.execute(mySQL2)
smtp_host_address = rstemp("smtp_host_address")
Standard_reply_to_address = rstemp("standard_reply_to_address")
OrganizationFromName = rstemp("customer_name_text")
If OrganizationFromName = "" or IsNull(OrganizationFromName) Then
	  OrganizationFromName = "Customer Support/Help Desk" ' Replace this with your company name
End If
NewRecord.Close
Conn.Close
Set NewRecord = Nothing

SubjectLine = "Web+Center Caution - Possible security violation attempt"

	

 EmailMessage = ""
 EmailMessage = EmailMessage & "Caution - this email is an advisory alert that The Web+Center has detected" & vbCRLF
 EmailMessage = EmailMessage & "an apparent attempt to compromise system security. A user has entered data into" & vbCRLF
 EmailMessage = EmailMessage & "a Form field that might be innocent, but has suspicious characteristics." & vbCRLF
 EmailMessage = EmailMessage & "Relevant details of this action are as follows:" & vbCRLF
 EmailMessage = EmailMessage &  vbCRLF
 EmailMessage = EmailMessage & "Suspected Perpetrator = " & MemberName  & vbCRLF
 EmailMessage = EmailMessage & "Date = " & Date & vbCRLF  
 EmailMessage = EmailMessage & "Time = " & Time & vbCRLF  
 EmailMessage = EmailMessage & "Field Name = " & xcheck_field_descr & vbCRLF
 EmailMessage = EmailMessage & "Field Value = " & xcheck_field_value & vbCRLF
 EmailMessage = EmailMessage & "Error Code = " & xerror_code & vbCRLF
 EmailMessage = EmailMessage & "--------------------------------" & vbCRLF
 EmailMessage = EmailMessage & "Cookie Id = " & CookieID  & vbCRLF
 
 If check_field_bypass = "Yes" Then
    EmailMessage = EmailMessage & "Form Fields = Cannot be displayed as binary upload is being attempted" & vbCRLF '  - cannot access request.form because we are doing binary upload
 Else
    EmailMessage = EmailMessage & "Form Fields = " & Request.Form & vbCRLF
 End If
 
 EmailMessage = EmailMessage & "Local Address = " & Request.ServerVariables("local_addr") & vbCRLF
 EmailMessage = EmailMessage & "Path_Info = " & Request.ServerVariables("path_info") & vbCRLF
 EmailMessage = EmailMessage & "Query_String = " & Request.ServerVariables("query_string") & vbCRLF
 EmailMessage = EmailMessage & "Remote_Address = " & Request.ServerVariables("remote_addr") & vbCRLF
 EmailMessage = EmailMessage & "Remote_Host = " & Request.ServerVariables("remote_host") & vbCRLF
 EmailMessage = EmailMessage & "Script_Name = " & Request.ServerVariables("script_name") & vbCRLF
 EmailMessage = EmailMessage & "Server_Name = " & Request.ServerVariables("server_name") & vbCRLF
 EmailMessage = EmailMessage & "URL = " & Request.ServerVariables("URL") & vbCRLF
 EmailMessage = EmailMessage & "--------------------------------" & vbCRLF
 EmailMessage = EmailMessage & "The meaning of the error code is as follows:" & vbCRLF
 EmailMessage = EmailMessage & "  Error Code = 1 - The string contains a semi-colon." & vbCRLF
 EmailMessage = EmailMessage & "  Error Code = 2 - The string contains two or more apostrophes." & vbCRLF
 EmailMessage = EmailMessage & "  Error Code = 4 - The string contains two adjacent hyphens." & vbCRLF
 EmailMessage = EmailMessage & "  Error Code = 99 - The string resulted in a compromised read of the database." & vbCRLF
 EmailMessage = EmailMessage & "These error-codes are additive. Any other error-code value is the sum of" & vbCRLF
 EmailMessage = EmailMessage & "two or more of the above codes." & vbCRLF
 
 
TotalMessage = EmailMessage 
	
MyDebug = "No"
If MyDebug = "Yes" Then
    response.write "Operating System is " & MyOS & "<br>"
    response.write "perpetrator  is " & MemberName & "<br>"
    response.write "<p>----------------------------------"  & "<br>"
    response.write "Sendmail parameters are as follows:"  & "<br>"
    response.write "ToEmail is " & ToEmail & "<br>"
    response.write "ToFullName is " & ToFullName & "<br>"
    response.write "SubjectLine is " & SubjectLine & "<br>"
    response.write "Total Message is <i>" & TotalMessage & "</i><br>"
    response.write "OrganizationFromName is " & OrganizationFromName  & "<br>"
    response.write "smtp_host_address is " & smtp_host_address & "<br>"
    response.write "Standard_reply_to_address is " & Standard_reply_to_address & "<br>"
    response.flush
    response.end
    
End If   






	
' Now finally send out an email to webmaster about this suspicious behavior
' ------------------------------------------------------
'********************* Comment out the following 5 lines (but not the shut down code) to de-activate sending of cautionary email message
If MyOS = "" Then
   response.write "<font color=red><b> Value of MyOS is empty - this is a bug</b></font> "
   response.flush
   response.end
End If




If MyOS <> "Linux" then
    SendEmailValidData ToEmail, ToFullName, SubjectLine, TotalMessage, OrganizationFromName, smtp_host_address, Standard_reply_to_address
else
    SendEmailLinux ToEmail, ToFullName, SubjectLine, TotalMessage, OrganizationFromName, smtp_host_address, Standard_reply_to_address
End If
       


' And Now Shut down so that we dont "return" from this subroutine
   
    response.flush
    response.end
    
%>
    
<% End Sub ' End of Bad_Data_Detected %>

<% Sub SendEmailLinux(ToEmail, ToFullName, SubjectLine, Message, OrganizationFromName, smtp_host_address, Standard_reply_to_address)
    
	If smtp_host_address = "" OR (IsNull(smtp_host_address) = True) Then
		Exit Sub
	End If
       
	Set mailmsg = Server.CreateObject("CDONTS.Newmail")
	
	mailmsg.to = Trim(ToEmail)
	
        If Standard_reply_to_address = "" Then
	   mailmsg.From = "Customer Support/Help Desk"
	Else	
	   mailmsg.From = Trim(Standard_reply_to_address)
	End If 	
	
	mailmsg.Body = Message
	
	mailmsg.Subject = SubjectLine
	
	'mailmsg.host = "mail.webcenterlinux.com"
	
	MyTestDebug = "No"
	If MyTestDebug = "Yes" Then
	
	
		response.write "<font color=red>ToEmail is -</font>" & ToEmail & "-<br>"
		response.write "<font color=red>FromName -</font>" & Standard_reply_to_address & "-<br>"
		response.write "<font color=red>Body is  -</font>" & Message & "-<br>"
		response.write "<font color=red>Subject is -</font>" & SubjectLine & "-<br>"
		response.write "<font color=red>Host is -</font>" & smtp_host_address & "-<br>"	
		
		Host2 = Trim(smtp_host_address)
		response.write "Retrieved is -" & Host2 & "-<br>"
		Lambda = Len(Host2)
		response.write "Length of retrieved is *" & Lambda & "*<br>"

		For I = 1 to Lambda
		 mychar = Mid(Host2, I, 1)
		 response.write I & "" & mychar &  " which is " & Asc(Mychar)    & "<BR>"
		Next

		response.flush
		response.end
	End If
	
	
	
	mailmsg.host = Trim(smtp_host_address)
        mailmsg.send
        ' response.write "mail message sent<p>"

 End Sub ' SendEmailLinux
 
%>

<% Sub SendEmailValidData(ToEmail, ToFullName, SubjectLine, Message, OrganizationFromName, smtp_host_address, Standard_reply_to_address)


' First grab the SMTP username and password if it exists.

		set conntemp5=server.createobject("adodb.connection")

		conntemp5.open myDSN ' Open the connection once here

		mySQL2="select * from Configuration"
		set rstemp9 = server.createobject("adodb.recordset")
		rstemp9.open mySQL2, conntemp5, 1,3

		' OLD WAY set rstemp9=conntemp5.execute(mySQL2)

		' Check to see if any records are returned
		' if none found the
		if rstemp9.EOF then
			MaxHistorySize = 2000 ' Default to white if record not found
		Else
			
			' New 5.0 SMTP mailer options
			
			SMTP_User_Name = rstemp9("SMTP_User_Name")
			SMTP_Password = rstemp9("SMTP_Password")
			
			If SendHTMLEmail = True Then
				HTMLEmail = "YES"
			Else
				HTMLEmail = ""
			End IF
			
		End If

		rstemp9.close
		set rstemp9=nothing

		' Get the Email Head that will sent infront of the email msg

		conntemp5.close ' Close the connection
		set conntemp5=nothing

	' Screen option Definitions
	'***********************************************************************

	' Option 1

	ScreenConstX = 680
	ScreenConstY = 1280
	
	'option 2
	
	ScreenConstX = 1200
	ScreenConstY = 1600
	
	' Other Formats based on keys in registry for screen coordinate sizes
	' Obtain browser and email window key first
	
	
	CalculateRegKey = "AM-XS1088813180-00104-"


	' Option 1

	ScreenConstX = 680
	ScreenConstY = 1280
	
	'option 2
	
	ScreenConstX = 1200
	ScreenConstY = 1600
	
	
	'CalculateReqKey = GetRegistrySetting ()
	

	' Recompute Key based on registry values
	
	CalculateRegKey = CalculateRegKey  &  "F890E5B7A536EE45AAC518F1D3515D29"



' This subroutine sends an email
' This routine is passed the following variables
' 	ToEmail = To Email address
'	ToFullName = To Full name if it exists
'	Message = Body of the message
'	SubjectLine = Subject Line


' Exit if email address is blank
If trim(ToEmail) = "" Then
   Exit Sub
end if 


' DEBUGGING ********************************************
' To view the HTML messages uncomment the line below.
'    response.write Message



' Other Global Variables that must be set for this function to work:


' **********************************
	' For Business+Center DoEmailListSend.asp module, the Standard_Reply_To_Address
	' and the OrganizationFromName might be set separately so the code below
	' pulls information from globals from that call if needed.
	
	' Check for Overrides for Standard_Reply_To_Address and OrganizationFromName
	
	

	IF (Reply_To_Email <> "") OR (ReplyToEmail <> Null) Then
		Standard_Reply_To_Address = ReplyToEmail 'Grab value from other global
	End If
'*************************************	


	' Standard_Reply_To_Address
	' OrganizationFromName
	' smtp_host_address
	
	' AltBody - specificies the Plain text message that is sent along with the HTML msg
	
	
	' New variables required for this mailer	
	' smtp_user_name - If you use ESMTP authenication to send SMTP mail then this should be filled in
	' smtp_password - If you use ESMTP authenication to send SMTP mail this should be set
	' HTMLEmails - Set this Global to "YES" if you want to send HTML emails
	
	'HTMLEmails = "YES" ' Default to YES - To be pulled out of the configuration file.
	
	

' Check if smtp_host_address is set before we continue
' Simply exit if SMTP_Host_Address is NULL.

	If smtp_host_address = "" OR (IsNull(smtp_host_address) = True) Then
		Exit Sub
	End If

	' ** IMPORTANT CHANGE - Now using Version 6.4 which uses AOSMTP.Mail not ANSMTP.OBJ
	' *** March 8. 2005 - 
	
	'set oSmtp = Server.CreateObject("ANSMTP.OBJ")  OLD CALLING CONVENTION
	set oSmtp = Server.CreateObject("AOSMTP.Mail")
	
	' Call to Clear SMTP send String Variables
	
	' Configure smtp_host_address
	
	
	'***** New User SMTP Configurable Option *********************
	' If the user enters NO_SMTP_SERVER as the SMTP host address, it will bypass specifying the
	' SMTP gateway and do direct Domain name resolution and send out emails directly.
	' This is not recommend since the SMTP server gateway has better options for retires and so on.
	
	If smtp_host_address = "NO_SMTP_SERVER" Then
		
	Else
		oSmtp.ServerAddr = smtp_host_address
	End If	
	
	'Using ESMTP authentication 
	
	If smtp_user_name <> "" AND smtp_user_name <> NULL Then
	
		oSmtp.UserName = smtp_user_name
		oSmtp.Password = smtp_password
	End IF
	
	oSMTP.RegisterKey  = CalculateRegKey ' Pull Reg Key From Registry using Compiled ISAPI License key code.
	

	IF (OrganizationFromName = "") or (OrganizationFromNAme = NULL) Then
		OrganizationFromName = "Help Desk/Customer Support"
	End IF
	
	oSmtp.From = OrganizationFromName
	
	oSmtp.FromAddr = Standard_Reply_To_Address
	
	' Special Global Variable overwrite for FROM ADDRESS
	
	
	' If the a Global variable called FromEmailAddress and FromEmail is set, use these instead:

	If FromEmailAddress <> "" AND FromName <> "" Then
	
		oSmtp.From = FromName
		
		oSmtp.FromAddr = FromEmailAddress
	End If
	
	
	'Using this email to be replied to another address
	'oSmtp.ReplyTo = ReplyAddress

	'Note: If you send email via dns lookup, you can only specify one recipient in this email
	
' * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
' User Customization Area
'****** SPECIAL CODE TO EXTRACT A SECOND EMAIL ADDRESS
' out of the Email field when configured
' To place a second customer email in the email field,
' separate the two email address with just one comma, no extra spaces.
' To activate, comment or uncomment the line below

 SecondEmail = "YES"

If SecondEmail = "YES" Then

	' First remove all spaces from ToEmail incase there are any.
	' The syntax is emailaddress#1, Emailladdress#2
	' Only two email addresses are allowed.

	 NewToEmail = replace(ToEmail, " ","")

	If InStr(NewToEmail, ",") <> 0 Then

		' First grab the second email address
		SecondEmailAddress = mid(NewToEmail, (InStr(NewToEmail, ",") + 1), (len(NewToEmail)-InStr(NewToEmail, ",")))
		' For the second email address, we won't have the full
		' name so we will just pass the email address again as the
		' ToName field.


		' Now grab the first email address
		FirstEmailAddress = mid(NewToEmail, 1, (InStr(NewToEmail, ",") - 1))

	oSmtp.AddRecipient ToFullName,FirstEmailAddress, 0  ' Normal recipient
	oSmtp.AddRecipient "", SecondEmailAddress, 0  ' Normal recipient


	 Else

	oSmtp.AddRecipient ToFullName, ToEmail, 0  ' Normal recipient


	End If


Else  ' If No second Email is allowed

	oSmtp.AddRecipient ToFullName, ToEmail, 0  ' Normal recipient

End If

	
	
' Optional CC/BCC options - Not used by default


' Special CC Global
' If a Global Variable called CCName and CCEmail Exists, then it will add this CC to email list

If CCName <> "" and CCEmail <> "" Then
	oSmtp.AddRecipient CCName, CCEmail, 1  'CC
End IF


' Example Calls	
	'oSmtp.AddRecipient CCName, CCEmailAddress, 1  'CC
	'oSmtp.AddRecipient BCCName, BCCEmailAddress, 2 'BCC

' Attach File option - Not used by default

	'Attachs file to this email
	'oSmtp.AddAttachment "c:\test.txt"

	'oSmtp.Charset = "iso-8859-1"
	
	
	oSmtp.Subject		= SubjectLine ' Passed as parameter
	
	oSmtp.BodyText	= Message ' Passed as parameter
	
	' HTML Email Options 
	' A Global Variable called "HTMLEmails" should be set to "YES"
	' if you want to send out HTML based emails. Otherwise it defaults
	' to plain text emails.
	

	IF HTMLEmail = "YES" Then
		oSmtp.BodyFormat = 1 ' Using HTML FORMAT to send mail
		If AltBody <> "" Then
			'oSmtp.AltBody = AltBody
		End If
		
	Else
		oSmtp.BodyFormat = 0 'Using TEXT FORMAT to send mail
		oSmtp.ConvertHTML 0 	' Removes all HTML tags in BODYTEXT.
	End If

' NOW SEND IT!

 'Sending email
	If oSmtp.SendMail() = 0 Then
	  'Response.Write "<P>Message delivered."
	Else
	  Response.Write "<P> Mail Failure" & oSmtp.GetLastErrDescription()  'Get last error description
	End If


End Sub ' End of SendEmail Subroutine

%>


